/*-------------------------------------------------------------------------
 |                                                                         
 |             SAS SUPPLEMENTAL SYNTAX FILE FOR ICPSR 02691
 |              SERVICES RESEARCH OUTCOMES STUDY, 1995-1996
 |              (DATASET 0001: FACILITY DIRECTOR INTERVIEW)
 |
 | This SAS program is provided for optional use with the SAS transport
 | version of this data file as distributed by ICPSR. The metadata
 | provided below are not stored in the SAS transport version of this data
 | collection.  Users need to use SAS PROC CIMPORT to import the SAS
 | transport file to a SAS data set on their system. This program can
 | then be used in conjunction with the SAS system data file.
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions.  Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set. Users
 | should replace "SAS-dataset" with their name for the SAS data set copied
 | from the SAS transport file. Users can add a SAS libname statement
 | and an output SAS data set name to make a permanent SAS data set.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .;
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables stored in the SAS data set. Users can refer to their
 | SAS manual for information on how to permanently store formats in a
 | SAS catalog.
 |
 | NOTE:  Users should modify this file to suit their specific needs.
 | The MISSING VALUE RECODES section has been commented out (i.e., '/*').
 | To make this section active in the program, users should remove the SAS
 | comment indicators from this section.
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

PROC FORMAT;
  VALUE yearcomp  -3='(-3) MISSING' ;
  VALUE month1ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE year1fff  -3='(-3) MISSING' ;
  VALUE month2ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE year2fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE month3ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE year3fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE month4ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE year4fff  -3='(-3) MISSING' ;
  VALUE month5ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE year5fff  -3='(-3) MISSING' ;
  VALUE change    1='(1) Yes' 2='(2) No' ;
  VALUE owner     -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE admin     -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE reorg     -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE othchang  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE numchang  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE oveffect  -3='(-3) MISSING' 1='(1) Major alterations in almost every aspect'
                  2='(2) Significant changes in at least one aspe'
                  3='(3) Minor changes only' 4='(4) No effect' ;
  VALUE effectiv  -3='(-3) MISSING' 1='(1) Improved clinical effectiveness'
                  2='(2) Reduced clinical effectiveness' 3='(3) No change' ;
  VALUE yearend   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE revenue   -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' ;
  VALUE pubrev    -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE pubrev2f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE privrev   -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE privrevf  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE pubins    -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE pubins2f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' ;
  VALUE npayhlf   -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE npayhlff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' ;
  VALUE outpat    -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hour24ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' ;
  VALUE othprog   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' ;
  VALUE fulltime  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE staff1ff  1='(1) Yes' 2='(2) No' ;
  VALUE left1fff  -3='(-3) MISSING' ;
  VALUE number1f  -3='(-3) MISSING' ;
  VALUE hours1ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE wage1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benefitf  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff2ff  1='(1) Yes' 2='(2) No' ;
  VALUE left2fff  -3='(-3) MISSING' ;
  VALUE number2f  -3='(-3) MISSING' ;
  VALUE hours2ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -1='(-1) REFUSED' ;
  VALUE wage2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benefi0f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff3ff  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE left3fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number3f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours3ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage3fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benefi1f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff4ff  1='(1) Yes' 2='(2) No' ;
  VALUE left4fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number4f  -3='(-3) MISSING' ;
  VALUE hours4ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage4fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE benefi2f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE staff5ff  1='(1) Yes' 2='(2) No' ;
  VALUE left5fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number5f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours5ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage5fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE benefi3f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE staff6ff  1='(1) Yes' 2='(2) No' ;
  VALUE left6fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number6f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours6ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' ;
  VALUE wage6fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE benefi4f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE staff7ff  1='(1) Yes' 2='(2) No' ;
  VALUE left7fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number7f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours7ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage7fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benefi5f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff8ff  1='(1) Yes' 2='(2) No' ;
  VALUE left8fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number8f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours8ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage8fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benefi6f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff9ff  1='(1) Yes' 2='(2) No' ;
  VALUE left9fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number9f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours9ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage9fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' ;
  VALUE benefi7f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff10f  1='(1) Yes' 2='(2) No' ;
  VALUE left10ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number0f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours10f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage10ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benefi8f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff11f  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE left11ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE numbe10f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours11f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage11ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benefi9f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff12f  1='(1) Yes' 2='(2) No' ;
  VALUE left12ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE numbe11f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours12f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage12ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benef10f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff13f  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE left13ff  -3='(-3) MISSING' ;
  VALUE numbe12f  -3='(-3) MISSING' ;
  VALUE hours13f  -3='(-3) MISSING' ;
  VALUE wage13ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benef11f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -1='(-1) REFUSED' ;
  VALUE volunt    -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE vhours    -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE vwage     -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE ownface   -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE value     -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE value2ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Month' 2='(2) Year' ;
  VALUE rent      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE rent2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Month' 2='(2) Year' ;
  VALUE utility   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE utilityf  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Month' 2='(2) Year' ;
  VALUE supply    -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE supply2f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Month' 2='(2) Year' ;
  VALUE equip     -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE ovhead    -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE othcost   -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE patients  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE finknow   -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Extensively based on records'
                  2='(2) Somewhat based on records' 3='(3) Based on estimate' ;
  VALUE datayr    -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) 1990' 2='(2) 1993' ;
  VALUE datadif   -3='(-3) MISSING' 1='(1) All financial information about the same'
                  2='(2) 1993 figures would be higher'
                  3='(3) 1993 figures would be lower' 4='(4) Other (SPECIFY)' ;
  VALUE percdiff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' ;
  VALUE statmnt   -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE copyst    -3='(-3) MISSING' 1='(1) Yes, report attached'
                  2='(2) Yes, report to be mailed'
                  3='(3) No, not specific enough to be useful'
                  4='(4) No, confidential' 5='(5) No, other reasons (SPECIFY)' ;
  VALUE partic    -3='(-3) MISSING' 1='(1) A great extent' 2='(2) A moderate extent'
                  3='(3) A small extent' ;
  VALUE abstin    -3='(-3) MISSING' 1='(1) A great extent' 2='(2) A moderate extent'
                  3='(3) A small extent' 4='(4) No extent' ;
  VALUE follow    -3='(-3) MISSING' 1='(1) A great extent' 2='(2) A moderate extent'
                  3='(3) A small extent' 4='(4) No extent' ;
  VALUE phone     -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE mail      -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE intview   -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE othmeth   -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE datacolf  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE dataco0f  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE dataco1f  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE report    -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE copyrep   -3='(-3) MISSING' 1='(1) Yes, report attached'
                  2='(2) Yes, report to be mailed'
                  3='(3) No, not specific enough to be useful'
                  4='(4) No, confidential' 5='(5) No, other reasons (SPECIFY)' ;
  VALUE alumni    -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE jcano     -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE carf      -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE mode      1='(1) Inpatient' 2='(2) Residential'
                  3='(3) Outpatient Methadone Maintenance'
                  4='(4) Outpatient Drug-Free' ;
RUN;

* SAS DATA STEP;
DATA;
SET SAS-dataset ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (FAC_ID <= -1) THEN FAC_ID = .;
   IF (YEARCOMP <= -1) THEN YEARCOMP = .;
   IF (MONTH1 <= -1) THEN MONTH1 = .;
   IF (YEAR1 <= -1) THEN YEAR1 = .;
   IF (MONTH2 <= -1) THEN MONTH2 = .;
   IF (YEAR2 <= -1) THEN YEAR2 = .;
   IF (MONTH3 <= -1) THEN MONTH3 = .;
   IF (YEAR3 <= -1) THEN YEAR3 = .;
   IF (MONTH4 <= -1) THEN MONTH4 = .;
   IF (YEAR4 <= -1) THEN YEAR4 = .;
   IF (MONTH5 <= -1) THEN MONTH5 = .;
   IF (YEAR5 <= -1) THEN YEAR5 = .;
   IF (CHANGE <= -1) THEN CHANGE = .;
   IF (OWNER <= -1) THEN OWNER = .;
   IF (ADMIN <= -1) THEN ADMIN = .;
   IF (REORG <= -1) THEN REORG = .;
   IF (OTHCHANG <= -1) THEN OTHCHANG = .;
   IF (NUMCHANG <= -1) THEN NUMCHANG = .;
   IF (OVEFFECT <= -1) THEN OVEFFECT = .;
   IF (EFFECTIV <= -1) THEN EFFECTIV = .;
   IF (YEAREND <= -1) THEN YEAREND = .;
   IF (REVENUE <= -1) THEN REVENUE = .;
   IF (PUBREV <= -1) THEN PUBREV = .;
   IF (PUBREV2 <= -1) THEN PUBREV2 = .;
   IF (PRIVREV <= -1) THEN PRIVREV = .;
   IF (PRIVREV2 <= -1) THEN PRIVREV2 = .;
   IF (PUBINS <= -1) THEN PUBINS = .;
   IF (PUBINS2 <= -1) THEN PUBINS2 = .;
   IF (NPAYHLF <= -1) THEN NPAYHLF = .;
   IF (NPAYHLF2 <= -1) THEN NPAYHLF2 = .;
   IF (OUTPAT <= -1) THEN OUTPAT = .;
   IF (HOUR24 <= -1) THEN HOUR24 = .;
   IF (OTHPROG <= -1) THEN OTHPROG = .;
   IF (FULLTIME <= -1) THEN FULLTIME = .;
   IF (STAFF1 <= -1) THEN STAFF1 = .;
   IF (LEFT1 <= -1) THEN LEFT1 = .;
   IF (NUMBER1 <= -1) THEN NUMBER1 = .;
   IF (HOURS1 <= -1) THEN HOURS1 = .;
   IF (WAGE1 <= -1) THEN WAGE1 = .;
   IF (BENEFIT1 <= -1) THEN BENEFIT1 = .;
   IF (STAFF2 <= -1) THEN STAFF2 = .;
   IF (LEFT2 <= -1) THEN LEFT2 = .;
   IF (NUMBER2 <= -1) THEN NUMBER2 = .;
   IF (HOURS2 <= -1) THEN HOURS2 = .;
   IF (WAGE2 <= -1) THEN WAGE2 = .;
   IF (BENEFIT2 <= -1) THEN BENEFIT2 = .;
   IF (STAFF3 <= -1) THEN STAFF3 = .;
   IF (LEFT3 <= -1) THEN LEFT3 = .;
   IF (NUMBER3 <= -1) THEN NUMBER3 = .;
   IF (HOURS3 <= -1) THEN HOURS3 = .;
   IF (WAGE3 <= -1) THEN WAGE3 = .;
   IF (BENEFIT3 <= -1) THEN BENEFIT3 = .;
   IF (STAFF4 <= -1) THEN STAFF4 = .;
   IF (LEFT4 <= -1) THEN LEFT4 = .;
   IF (NUMBER4 <= -1) THEN NUMBER4 = .;
   IF (HOURS4 <= -1) THEN HOURS4 = .;
   IF (WAGE4 <= -1) THEN WAGE4 = .;
   IF (BENEFIT4 <= -1) THEN BENEFIT4 = .;
   IF (STAFF5 <= -1) THEN STAFF5 = .;
   IF (LEFT5 <= -1) THEN LEFT5 = .;
   IF (NUMBER5 <= -1) THEN NUMBER5 = .;
   IF (HOURS5 <= -1) THEN HOURS5 = .;
   IF (WAGE5 <= -1) THEN WAGE5 = .;
   IF (BENEFIT5 <= -1) THEN BENEFIT5 = .;
   IF (STAFF6 <= -1) THEN STAFF6 = .;
   IF (LEFT6 <= -1) THEN LEFT6 = .;
   IF (NUMBER6 <= -1) THEN NUMBER6 = .;
   IF (HOURS6 <= -1) THEN HOURS6 = .;
   IF (WAGE6 <= -1) THEN WAGE6 = .;
   IF (BENEFIT6 <= -1) THEN BENEFIT6 = .;
   IF (STAFF7 <= -1) THEN STAFF7 = .;
   IF (LEFT7 <= -1) THEN LEFT7 = .;
   IF (NUMBER7 <= -1) THEN NUMBER7 = .;
   IF (HOURS7 <= -1) THEN HOURS7 = .;
   IF (WAGE7 <= -1) THEN WAGE7 = .;
   IF (BENEFIT7 <= -1) THEN BENEFIT7 = .;
   IF (STAFF8 <= -1) THEN STAFF8 = .;
   IF (LEFT8 <= -1) THEN LEFT8 = .;
   IF (NUMBER8 <= -1) THEN NUMBER8 = .;
   IF (HOURS8 <= -1) THEN HOURS8 = .;
   IF (WAGE8 <= -1) THEN WAGE8 = .;
   IF (BENEFIT8 <= -1) THEN BENEFIT8 = .;
   IF (STAFF9 <= -1) THEN STAFF9 = .;
   IF (LEFT9 <= -1) THEN LEFT9 = .;
   IF (NUMBER9 <= -1) THEN NUMBER9 = .;
   IF (HOURS9 <= -1) THEN HOURS9 = .;
   IF (WAGE9 <= -1) THEN WAGE9 = .;
   IF (BENEFIT9 <= -1) THEN BENEFIT9 = .;
   IF (STAFF10 <= -1) THEN STAFF10 = .;
   IF (LEFT10 <= -1) THEN LEFT10 = .;
   IF (NUMBER10 <= -1) THEN NUMBER10 = .;
   IF (HOURS10 <= -1) THEN HOURS10 = .;
   IF (WAGE10 <= -1) THEN WAGE10 = .;
   IF (BENEFI10 <= -1) THEN BENEFI10 = .;
   IF (STAFF11 <= -1) THEN STAFF11 = .;
   IF (LEFT11 <= -1) THEN LEFT11 = .;
   IF (NUMBER11 <= -1) THEN NUMBER11 = .;
   IF (HOURS11 <= -1) THEN HOURS11 = .;
   IF (WAGE11 <= -1) THEN WAGE11 = .;
   IF (BENEFI11 <= -1) THEN BENEFI11 = .;
   IF (STAFF12 <= -1) THEN STAFF12 = .;
   IF (LEFT12 <= -1) THEN LEFT12 = .;
   IF (NUMBER12 <= -1) THEN NUMBER12 = .;
   IF (HOURS12 <= -1) THEN HOURS12 = .;
   IF (WAGE12 <= -1) THEN WAGE12 = .;
   IF (BENEFI12 <= -1) THEN BENEFI12 = .;
   IF (STAFF13 <= -1) THEN STAFF13 = .;
   IF (LEFT13 <= -1) THEN LEFT13 = .;
   IF (NUMBER13 <= -1) THEN NUMBER13 = .;
   IF (HOURS13 <= -1) THEN HOURS13 = .;
   IF (WAGE13 <= -1) THEN WAGE13 = .;
   IF (BENEFI13 <= -1) THEN BENEFI13 = .;
   IF (VOLUNT <= -1) THEN VOLUNT = .;
   IF (VHOURS <= -1) THEN VHOURS = .;
   IF (VWAGE <= -1) THEN VWAGE = .;
   IF (OWNFACE <= -1) THEN OWNFACE = .;
   IF (VALUE <= -1) THEN VALUE = .;
   IF (VALUE2 <= -1) THEN VALUE2 = .;
   IF (RENT <= -1) THEN RENT = .;
   IF (RENT2 <= -1) THEN RENT2 = .;
   IF (UTILITY <= -1) THEN UTILITY = .;
   IF (UTILITY2 <= -1) THEN UTILITY2 = .;
   IF (SUPPLY <= -1) THEN SUPPLY = .;
   IF (SUPPLY2 <= -1) THEN SUPPLY2 = .;
   IF (EQUIP <= -1) THEN EQUIP = .;
   IF (OVHEAD <= -1) THEN OVHEAD = .;
   IF (OTHCOST <= -1) THEN OTHCOST = .;
   IF (PATIENTS <= -1) THEN PATIENTS = .;
   IF (FINKNOW <= -1) THEN FINKNOW = .;
   IF (DATAYR <= -1) THEN DATAYR = .;
   IF (DATADIF <= -1) THEN DATADIF = .;
   IF (PERCDIFF <= -1) THEN PERCDIFF = .;
   IF (STATMNT <= -1) THEN STATMNT = .;
   IF (COPYST <= -1) THEN COPYST = .;
   IF (PARTIC <= -1) THEN PARTIC = .;
   IF (ABSTIN <= -1) THEN ABSTIN = .;
   IF (FOLLOW <= -1) THEN FOLLOW = .;
   IF (PHONE <= -1) THEN PHONE = .;
   IF (MAIL <= -1) THEN MAIL = .;
   IF (INTVIEW <= -1) THEN INTVIEW = .;
   IF (OTHMETH <= -1) THEN OTHMETH = .;
   IF (DATACOL1 <= -1) THEN DATACOL1 = .;
   IF (DATACOL2 <= -1) THEN DATACOL2 = .;
   IF (DATACOL3 <= -1) THEN DATACOL3 = .;
   IF (REPORT <= -1) THEN REPORT = .;
   IF (COPYREP <= -1) THEN COPYREP = .;
   IF (ALUMNI <= -1) THEN ALUMNI = .;
   IF (JCANO <= -1) THEN JCANO = .;
   IF (CARF <= -1) THEN CARF = .;
   IF (MODE <= -1) THEN MODE = .;
*/

* SAS FORMAT STATEMENT;

  FORMAT YEARCOMP yearcomp. MONTH1 month1ff. YEAR1 year1fff.
         MONTH2 month2ff. YEAR2 year2fff. MONTH3 month3ff.
         YEAR3 year3fff. MONTH4 month4ff. YEAR4 year4fff.
         MONTH5 month5ff. YEAR5 year5fff. CHANGE change.
         OWNER owner. ADMIN admin. REORG reorg.
         OTHCHANG othchang. NUMCHANG numchang. OVEFFECT oveffect.
         EFFECTIV effectiv. YEAREND yearend. REVENUE revenue.
         PUBREV pubrev. PUBREV2 pubrev2f. PRIVREV privrev.
         PRIVREV2 privrevf. PUBINS pubins. PUBINS2 pubins2f.
         NPAYHLF npayhlf. NPAYHLF2 npayhlff. OUTPAT outpat.
         HOUR24 hour24ff. OTHPROG othprog. FULLTIME fulltime.
         STAFF1 staff1ff. LEFT1 left1fff. NUMBER1 number1f.
         HOURS1 hours1ff. WAGE1 wage1fff. BENEFIT1 benefitf.
         STAFF2 staff2ff. LEFT2 left2fff. NUMBER2 number2f.
         HOURS2 hours2ff. WAGE2 wage2fff. BENEFIT2 benefi0f.
         STAFF3 staff3ff. LEFT3 left3fff. NUMBER3 number3f.
         HOURS3 hours3ff. WAGE3 wage3fff. BENEFIT3 benefi1f.
         STAFF4 staff4ff. LEFT4 left4fff. NUMBER4 number4f.
         HOURS4 hours4ff. WAGE4 wage4fff. BENEFIT4 benefi2f.
         STAFF5 staff5ff. LEFT5 left5fff. NUMBER5 number5f.
         HOURS5 hours5ff. WAGE5 wage5fff. BENEFIT5 benefi3f.
         STAFF6 staff6ff. LEFT6 left6fff. NUMBER6 number6f.
         HOURS6 hours6ff. WAGE6 wage6fff. BENEFIT6 benefi4f.
         STAFF7 staff7ff. LEFT7 left7fff. NUMBER7 number7f.
         HOURS7 hours7ff. WAGE7 wage7fff. BENEFIT7 benefi5f.
         STAFF8 staff8ff. LEFT8 left8fff. NUMBER8 number8f.
         HOURS8 hours8ff. WAGE8 wage8fff. BENEFIT8 benefi6f.
         STAFF9 staff9ff. LEFT9 left9fff. NUMBER9 number9f.
         HOURS9 hours9ff. WAGE9 wage9fff. BENEFIT9 benefi7f.
         STAFF10 staff10f. LEFT10 left10ff. NUMBER10 number0f.
         HOURS10 hours10f. WAGE10 wage10ff. BENEFI10 benefi8f.
         STAFF11 staff11f. LEFT11 left11ff. NUMBER11 numbe10f.
         HOURS11 hours11f. WAGE11 wage11ff. BENEFI11 benefi9f.
         STAFF12 staff12f. LEFT12 left12ff. NUMBER12 numbe11f.
         HOURS12 hours12f. WAGE12 wage12ff. BENEFI12 benef10f.
         STAFF13 staff13f. LEFT13 left13ff. NUMBER13 numbe12f.
         HOURS13 hours13f. WAGE13 wage13ff. BENEFI13 benef11f.
         VOLUNT volunt. VHOURS vhours. VWAGE vwage.
         OWNFACE ownface. VALUE value. VALUE2 value2ff.
         RENT rent. RENT2 rent2fff. UTILITY utility.
         UTILITY2 utilityf. SUPPLY supply. SUPPLY2 supply2f.
         EQUIP equip. OVHEAD ovhead. OTHCOST othcost.
         PATIENTS patients. FINKNOW finknow. DATAYR datayr.
         DATADIF datadif. PERCDIFF percdiff. STATMNT statmnt.
         COPYST copyst. PARTIC partic. ABSTIN abstin.
         FOLLOW follow. PHONE phone. MAIL mail.
         INTVIEW intview. OTHMETH othmeth. DATACOL1 datacolf.
         DATACOL2 dataco0f. DATACOL3 dataco1f. REPORT report.
         COPYREP copyrep. ALUMNI alumni. JCANO jcano.
         CARF carf. MODE mode.  ;

RUN ;
